@@ -1,8 +1,12 @@
 package Text::CSV::Encoded;
-$Text::CSV::Encoded::VERSION = '0.24';
+$Text::CSV::Encoded::VERSION = '0.25';
 use strict;
+use warnings;
 use Carp ();
 
+# VERSION
+
+
 BEGIN {
     require Text::CSV;
     if ( Text::CSV->VERSION < 1.06 ) {
@@ -253,6 +257,10 @@ __END__
 
 Text::CSV::Encoded - Encoding aware Text::CSV.
 
+=head1 VERSION
+
+version 0.25
+
 =head1 SYNOPSIS
 
     # Here in Perl 5.8 or later
@@ -265,6 +273,8 @@ Text::CSV::Encoded - Encoding aware Text::CSV.
     $csv->parse( $line );      # $line is a iso-8859-1 encoded string
     @columns = $csv->fields(); # they are unicode data
 
+=for readme stop
+
     # combining list is regarded as output
     $csv->combine(@columns);   # they are unicode data
     $line = $csv->string();    # $line is a cp1252 encoded string
@@ -298,11 +308,54 @@ Text::CSV::Encoded - Encoding aware Text::CSV.
     # pass check value to coder class
     $csv->coder->encode_check_value( Encode::FB_PERLQQ );
 
+=for readme start
 
 =head1 DESCRIPTION
 
 This module inherits L<Text::CSV> and is aware of input/output encodings.
 
+=begin :readme
+
+=head1 INSTALLATION 
+
+This module sources are hosted on github 
+https://github.com/singingfish/Text-CSV-Encoded 
+and uses C<Dist::Zilla> to generate the distribution. It can be 
+istalled:
+
+=over
+
+=item directly
+
+ cpanm https://github.com/singingfish/Text-CSV-Encoded.git
+
+=item from CPAN
+
+ cpan Text::CSV::Encoded
+ cpanm https://github.com/singingfish/Text-CSV-Encoded
+
+=item maualy cloninig the repository:
+
+ git clone https://github.com/singingfish/Text-CSV-Encoded.git
+ cd https://github.com/singingfish/Text-CSV-Encoded
+ perl Makefile.PL
+ make
+ make test
+ make install
+
+=back
+
+=for readme plugin requires
+
+=head1 COPYRIGHT AND LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=end :readme
+
+=for readme stop
+
 =head1 ENCODINGS
 
 Acceptable names of encodings (C<encoding_in>, C<encoding_out> and C<encoding>)
